/*  -- translated by f2c (version 20100827).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
integer isgtrc_(char *ctr, ftnlen ctr_len)
{
    /* System generated locals */
    integer ret_val;

    /* Local variables */
    static integer nc, ntx;
    extern integer lenc_(char *, ftnlen);
    extern /* Subroutine */ int sgtrln_(char *, integer *, ftnlen), sgtrsn_(
	    char *, integer *, ftnlen);

    nc = lenc_(ctr, ctr_len);
    if (nc == 3) {
	sgtrsn_(ctr, &ntx, ctr_len);
    } else {
	sgtrln_(ctr, &ntx, ctr_len);
    }
    ret_val = ntx;
    return ret_val;
} /* isgtrc_ */

